<?php 
/**
 *
 * @category        modules
 * @package         minigallery
 * @author          Ruud Eisinga
 * @link			http://www.allwww.nl/
 * @license         http://www.gnu.org/licenses/gpl.html
 * @platform        WebsiteBaker 2.8.x
 * @requirements    PHP 5.2.2 and higher
 * @version         0.2
 * @lastmodified    19 aug 2011
 *
 */
//Used for some default values and internal functions
require_once (WB_PATH.'/framework/functions.php');

$basedir = WB_PATH.MEDIA_DIRECTORY.'/minigallery/';
$baseurl = WB_URL.MEDIA_DIRECTORY.'/minigallery/';


if (!function_exists('getImages')) {
	function getImages($basedir,$dir) {
		$retval = array();
		$imagetypes = array("image/jpeg", "image/gif", "image/png");
		if(substr($dir, -1) != "/")  $dir .= "/";
		$fulldir = $basedir.''.$dir;
		$d = @dir($fulldir) or die("getImages: Failed opening directory $fulldir for reading");
		while(false !== ($entry = $d->read())) {
		  if($entry[0] == ".") continue;
		  if(in_array(mime_content_type($fulldir.$entry), $imagetypes)) {
			$retval[] = array( "file" => ''.$dir.$entry );
		  }
		}
		$d->close();
		asort($retval);
		return $retval;
	}
}

if (!function_exists('do_resize')) {
	function do_resize($source, $destination, $size, $crop = 0) {

		$cropfile = $source;
		$source_img = @imagecreatefromjpeg($cropfile); //Create a copy of our image for our thumbnails...
		if (!$source_img) {
			return false;
		}
		$orig_w = imagesx($source_img);
		$orig_h = imagesy($source_img);
		$src_x = 0;
		$src_y = 0;

		if(!$crop) {
			
			if ($orig_w < $size && $orig_h < $size ) { 
				return false;  //Image smaller than resize size
			}
			if ($orig_w > $orig_h) {
				$crop_w = $size;
				$crop_h = $orig_h*($size/$orig_w);
			}
			if ($orig_w < $orig_h) {
				$crop_w = $orig_w*($size/$orig_h);
				$crop_h = $size;
			}
			if ($orig_w == $orig_h) {
				$crop_w = $size;
				$crop_h = $size;	
			}
			$new_h = $crop_h;
			$new_w = $crop_w;
			
		} else {
			
			$w_ratio = ($size / $orig_w);
			$h_ratio = ($size / $orig_h);
			$new_h = $size;
			$new_w = $size;
				
			if ($orig_w < $size && $orig_h < $size ) { 
				return false;  //Image smaller than resize size
			}
			if ($orig_w > $orig_h ) {
				$crop_w = round($orig_w * $h_ratio);
				$crop_h = $size;
				$src_x = ceil( ( $orig_w - $orig_h ) / 2 );
				$src_y = 0;
			} elseif ($orig_w < $orig_h ) {
				$crop_h = round($orig_h * $w_ratio);
				$crop_w = $size;
				$src_x = 0;
				$src_y = ceil( ( $orig_h - $orig_w ) / 2 );
			} else {
				$crop_w = $size;
				$crop_h = $size;
				$src_x = 0;
				$src_y = 0;
			}
		}
		
		
		$dest_img = imagecreatetruecolor($new_w,$new_h);
		imagecopyresampled($dest_img, $source_img, 0 , 0 , $src_x, $src_y, $crop_w, $crop_h, $orig_w, $orig_h); 
		if(imagejpeg($dest_img, $destination)){
			imagedestroy($dest_img);
			imagedestroy($source_img);
		} 
	}
}


if (!function_exists('smart_resize_image')) {

	function smart_resize_image( $source, $output_file, $size, $crop ) {

		$info = getimagesize($source);
		list($orig_w, $orig_h) = $info;
		$src_x = 0;
		$src_y = 0;

		if(!$crop) {
			
			if ($orig_w < $size && $orig_h < $size ) { 
				return false;  //Image smaller than resize size
			}
			if ($orig_w > $orig_h) {
				$crop_w = $size;
				$crop_h = $orig_h*($size/$orig_w);
			}
			if ($orig_w < $orig_h) {
				$crop_w = $orig_w*($size/$orig_h);
				$crop_h = $size;
			}
			if ($orig_w == $orig_h) {
				$crop_w = $size;
				$crop_h = $size;	
			}
			$new_h = $crop_h;
			$new_w = $crop_w;
			
		} else {
			
			$w_ratio = ($size / $orig_w);
			$h_ratio = ($size / $orig_h);
			$new_h = $size;
			$new_w = $size;
				
			if ($orig_w < $size && $orig_h < $size ) { 
				return false;  //Image smaller than resize size
			}
			if ($orig_w > $orig_h ) {
				$crop_w = round($orig_w * $h_ratio);
				$crop_h = $size;
				$src_x = ceil( ( $orig_w - $orig_h ) / 2 );
				$src_y = 0;
			} elseif ($orig_w < $orig_h ) {
				$crop_h = round($orig_h * $w_ratio);
				$crop_w = $size;
				$src_x = 0;
				$src_y = ceil( ( $orig_h - $orig_w ) / 2 );
			} else {
				$crop_w = $size;
				$crop_h = $size;
				$src_x = 0;
				$src_y = 0;
			}
		}

		switch ( $info[2] ) {
		  case IMAGETYPE_GIF:
			$image = imagecreatefromgif($source);
		  break;
		  case IMAGETYPE_JPEG:
			$image = imagecreatefromjpeg($source);
		  break;
		  case IMAGETYPE_PNG:
			$image = imagecreatefrompng($source);
		  break;
		  default:
			return false;
		}

		$dest_img = imagecreatetruecolor($new_w,$new_h);
		   
		if ( ($info[2] == IMAGETYPE_GIF) || ($info[2] == IMAGETYPE_PNG) ) {
		  $trnprt_indx = imagecolortransparent($image);
		  if ($trnprt_indx >= 0) {
			$trnprt_color    = imagecolorsforindex($image, $trnprt_indx);
			$trnprt_indx    = imagecolorallocate($dest_img, $trnprt_color['red'], $trnprt_color['green'], $trnprt_color['blue']);
			imagefill($dest_img, 0, 0, $trnprt_indx);
			imagecolortransparent($dest_img, $trnprt_indx);
		  }
		  elseif ($info[2] == IMAGETYPE_PNG) {
			imagealphablending($dest_img, false);
			$color = imagecolorallocatealpha($dest_img, 0, 0, 0, 127);
			imagefill($dest_img, 0, 0, $color);
			imagesavealpha($dest_img, true);
		  }
		}

		imagecopyresampled($dest_img, $image, 0 , 0 , $src_x, $src_y, $crop_w, $crop_h, $orig_w, $orig_h); 

		switch ( $info[2] ) {
		  case IMAGETYPE_GIF:
			imagegif($dest_img, $output_file);
		  break;
		  case IMAGETYPE_JPEG:
			imagejpeg($dest_img, $output_file);
		  break;
		  case IMAGETYPE_PNG:
			imagepng($dest_img, $output_file);
		  break;
		  default:
			return false;
		}

		return true;
	  }
}